@@ -1,10 +1,10 @@
 import QuantLib as ql 
-from pymodels import *
-from ql_utils import *
-from ql_conventions import *
+from .pymodels import *
+from .ql_utils import *
+from .ql_conventions import *
 
 
-def get_qlfixedratebond(value_date: str, bond_info: FixedRateBond, setting: BondSetting,
+def get_qlfixedratebond(bond_info: FixedRateBond, setting: BondSetting,
                 calendar):
     schedule = ql.Schedule(datestr_to_qldate(bond_info.issue_date), 
                             datestr_to_qldate(bond_info.maturity), 
