@@ -152,7 +152,10 @@ ql_calendar_market = {
     "UnitedStates (NYSE)": ql.UnitedStates(ql.UnitedStates.NYSE),
     "UnitedStates (Settlement)": ql.UnitedStates(ql.UnitedStates.Settlement) ,
     "TARGET": ql.TARGET(),
+    "WeekendsOnly": ql.WeekendsOnly(),
     "NullCalendar": ql.NullCalendar()
 }
 
+ql_start_basis = { "Today": 0, "Tom": 1, "Spot": 2}
+
 
